==> alibabacloud_fc-open20210406_py2-1.1.9.tar.gz: alibabacloud_fc-open20210406_py2-1.1.9/setup.py <==
# -*- coding: utf-8 -*-
"""
 Licensed to the Apache Software Foundation (ASF) under one
 or more contributor license agreements.  See the NOTICE file
 distributed with this work for additional information
 regarding copyright ownership.  The ASF licenses this file
 to you under the Apache License, Version 2.0 (the
 "License"); you may not use this file except in compliance
 with the License.  You may obtain a copy of the License at

     http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing,
 software distributed under the License is distributed on an
 "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 KIND, either express or implied.  See the License for the
 specific language governing permissions and limitations
 under the License.
"""

import os
import sys
from setuptools import setup, find_packages

"""
setup module for alibabacloud_fc-open20210406_py2.

Created on 11/08/2022

@author: Alibaba Cloud SDK
"""

PACKAGE = "alibabacloud_fc_open20210406"
NAME = "alibabacloud_fc-open20210406_py2" or "alibabacloud-package"
DESCRIPTION = "Alibaba Cloud FC-Open (20210406) SDK Library for Python2"
AUTHOR = "Alibaba Cloud SDK"
AUTHOR_EMAIL = "sdk-team@alibabacloud.com"
URL = "https://github.com/aliyun/alibabacloud-python2-sdk"
VERSION = __import__(PACKAGE).__version__
REQUIRES = [
    "alibabacloud_tea_util_py2>=0.0.6, <1.0.0",
    "alibabacloud_tea_openapi_py2>=0.1.3, <1.0.0",
    "alibabacloud_openapi_util_py2>=0.0.8, <1.0.0",
    "alibabacloud_endpoint_util_py2>=0.0.2, <1.0.0"
]

LONG_DESCRIPTION = ''

if os.path.exists('./README.md'):
    if sys.version_info.major == 2:
        with open("README.md") as fp:
            LONG_DESCRIPTION = fp.read()
    else:
        with open("README.md", encoding="utf-8") as fp:
            LONG_DESCRIPTION = fp.read()

setup(
    name=NAME,
    version=VERSION,
    description=DESCRIPTION,
    long_description=LONG_DESCRIPTION,
    long_description_content_type='text/markdown',
    author=AUTHOR,
    author_email=AUTHOR_EMAIL,
    license="Apache License 2.0",
    url=URL,
    keywords=["alibabacloud","fc","open20210406","py2"],
    packages=find_packages(exclude=["tests*"]),
    include_package_data=True,
    platforms="any",
    install_requires=REQUIRES,
    classifiers=(
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: Apache Software License",
        "Programming Language :: Python",
        "Programming Language :: Python :: 2",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Topic :: Software Development"
    )
)

==> alibabacloud_fc-open20210406_py2-1.1.10.tar.gz: alibabacloud_fc-open20210406_py2-1.1.10/setup.py <==
# -*- coding: utf-8 -*-
"""
 Licensed to the Apache Software Foundation (ASF) under one
 or more contributor license agreements.  See the NOTICE file
 distributed with this work for additional information
 regarding copyright ownership.  The ASF licenses this file
 to you under the Apache License, Version 2.0 (the
 "License"); you may not use this file except in compliance
 with the License.  You may obtain a copy of the License at

     http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing,
 software distributed under the License is distributed on an
 "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 KIND, either express or implied.  See the License for the
 specific language governing permissions and limitations
 under the License.
"""

import os
import sys
from setuptools import setup, find_packages

"""
setup module for alibabacloud_fc-open20210406_py2.

Created on 02/09/2022

@author: Alibaba Cloud SDK
"""

PACKAGE = "alibabacloud_fc_open20210406"
NAME = "alibabacloud_fc-open20210406_py2" or "alibabacloud-package"
DESCRIPTION = "Alibaba Cloud FC-Open (20210406) SDK Library for Python2"
AUTHOR = "Alibaba Cloud SDK"
AUTHOR_EMAIL = "sdk-team@alibabacloud.com"
URL = "https://github.com/aliyun/alibabacloud-python2-sdk"
VERSION = __import__(PACKAGE).__version__
REQUIRES = [
    "alibabacloud_tea_util_py2>=0.0.6, <1.0.0",
    "alibabacloud_tea_openapi_py2>=0.1.3, <1.0.0",
    "alibabacloud_openapi_util_py2>=0.0.8, <1.0.0",
    "alibabacloud_endpoint_util_py2>=0.0.2, <1.0.0",
    "alibabacloud_credentials_py2>=0.0.1, <1.0.0",
    "requests>=2.21.0, <3.0.0",
    "alibabacloud_gateway_fc_util_py2>=0.0.1, <1.0.0"
]

LONG_DESCRIPTION = ''

if os.path.exists('./README.md'):
    if sys.version_info.major == 2:
        with open("README.md") as fp:
            LONG_DESCRIPTION = fp.read()
    else:
        with open("README.md", encoding="utf-8") as fp:
            LONG_DESCRIPTION = fp.read()

setup(
    name=NAME,
    version=VERSION,
    description=DESCRIPTION,
    long_description=LONG_DESCRIPTION,
    long_description_content_type='text/markdown',
    author=AUTHOR,
    author_email=AUTHOR_EMAIL,
    license="Apache License 2.0",
    url=URL,
    keywords=["alibabacloud","fc","open20210406","py2"],
    packages=find_packages(exclude=["tests*"]),
    include_package_data=True,
    platforms="any",
    install_requires=REQUIRES,
    classifiers=(
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: Apache Software License",
        "Programming Language :: Python",
        "Programming Language :: Python :: 2",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Topic :: Software Development"
    )
)
